import { RabbitSubscribe } from '@golevelup/nestjs-rabbitmq';
import { Controller, Inject } from '@nestjs/common';
import { WINSTON_MODULE_PROVIDER } from 'nest-winston';
import { Logger } from 'winston';
import { level } from './logger/level.enum';
import loggerOptions from './logger/logger';

@Controller()
export class AdController {
  constructor(
    @Inject(WINSTON_MODULE_PROVIDER) private readonly logger: Logger,
  ) {}

  @RabbitSubscribe({
    name: 'loggingAdCreateInfo',
  })
  public async adCreatedInfoHandler(message: string) {
    this.logger.configure(loggerOptions('ad', level.info, 'info', 'create'));
    this.logger.info(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAdCreateWarning',
  })
  public async adCreatedWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('ad', level.warning, 'warning', 'create'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAdCreateCrit',
  })
  public async adCreatedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('ad', level.crit, 'critical', 'create'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAdDeleteInfo',
  })
  public async adDeletedInfoHandler(message: string) {
    this.logger.configure(loggerOptions('ad', level.info, 'info', 'delete'));
    this.logger.info(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAdDeleteCrit',
  })
  public async adDeletedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('ad', level.crit, 'critical', 'delete'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAdReadWarning',
  })
  public async adReadWarningHandler(message: string) {
    this.logger.configure(
      loggerOptions('ad', level.warning, 'warning', 'read'),
    );
    this.logger.warning(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAdUpdateInfo',
  })
  public async adUpdatedInfoHandler(message: string) {
    this.logger.configure(loggerOptions('ad', level.info, 'info', 'update'));
    this.logger.info(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAdUpdateCrit',
  })
  public async adUpdatedCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('ad', level.crit, 'critical', 'update'),
    );
    this.logger.crit(JSON.parse(message));
  }

  @RabbitSubscribe({
    name: 'loggingAdHealthCrit',
  })
  public async adHealthCriticalHandler(message: string) {
    this.logger.configure(
      loggerOptions('ad', level.crit, 'critical', 'health'),
    );
    this.logger.crit(JSON.parse(message));
  }
}
